@@ -9,7 +9,7 @@ use Scalar::Util qw(reftype blessed);
 
 use JIP::Mock::Event;
 
-our $VERSION = 'v0.0.2';
+our $VERSION = 'v0.0.3';
 
 sub new {
     my ( $class, %param ) = @ARG;
@@ -70,6 +70,38 @@ sub override {
     return;
 } ## end sub override
 
+sub call_original {
+    my ( $self, $name, @arguments ) = @ARG;
+
+    if ( my $error = $self->_validate_call_original($name) ) {
+        croak 'Cannot call original: ' . $error;
+    }
+
+    my $want_array   = wantarray;
+    my $original_sub = $self->_get_original($name);
+
+    # void context
+    if ( !defined $want_array ) {
+        $original_sub->(@arguments);
+
+        return;
+    }
+
+    # is looking for a list value
+    elsif ($want_array) {
+        my @results = $original_sub->(@arguments);
+
+        return @results;
+    }
+
+    # is looking for a scalar
+    else {
+        my $result = $original_sub->(@arguments);
+
+        return $result;
+    }
+} ## end sub call_original
+
 sub DESTROY {
     my ($self) = @ARG;
 
@@ -108,6 +140,16 @@ sub _validate_overriding {
     return sprintf 'new sub of "%s" is not CODE reference!', $name;
 }
 
+sub _validate_call_original {
+    my ( $self, $name ) = @ARG;
+
+    return 'name is not present!' if !length $name;
+
+    return if $self->_get_original($name);
+
+    return sprintf 'cannot find sub "%s" by name!', $name;
+}
+
 sub _instantiate {
     my ( $class, %param ) = @ARG;
 
@@ -354,7 +396,7 @@ JIP::Mock::Control - Override subroutines in a module
 
 =head1 VERSION
 
-This document describes L<JIP::Mock::Control> version C<v0.0.2>.
+This document describes L<JIP::Mock::Control> version C<v0.0.3>.
 
 =head1 SYNOPSIS
 
@@ -515,6 +557,12 @@ Build new L<JIP::Mock::Control> object.
 
 Temporarily replaces one or more subroutines in the mocked module.
 
+=head2 call_original
+
+    $control->call_original( 'name', @arguments );
+
+Calls the original (unmocked) subroutine.
+
 =head1 DIAGNOSTICS
 
 None.
